=======
Credits
=======

Development Lead
----------------

* `hXtreme <https://github.com/hXtreme>`_ <harsh_parekh@outlook.com> : Project manager.

Contributors
------------

None yet. Why not be the first?

Special Thanks
--------------

* `audreyr <https://github.com/audreyr>`_ : For the `cookiecutter template <https://github.com/audreyr/cookiecutter-pypackage>`_.

